summaryrefslogtreecommitdiff
path: root/tar
diff options
context:
space:
mode:
authorMichihiro NAKAJIMA <ggcueroad@gmail.com>2012-10-14 14:08:46 +0900
committerMichihiro NAKAJIMA <ggcueroad@gmail.com>2012-10-14 14:08:46 +0900
commitd857349722b642d2561238ebc5883e83eae161a2 (patch)
tree3bfa5ebd428a2b16f8f7771849497949f354fe2e /tar
parent5fa19d2720aef965e88d297f5c58cac556c41f03 (diff)
downloadlibarchive-d857349722b642d2561238ebc5883e83eae161a2.tar.gz
Switch an external program for lzma decompression from "unlzma" to
"lzma -d".
Diffstat (limited to 'tar')
-rw-r--r--tar/test/main.c6
-rw-r--r--tar/test/test.h4
-rw-r--r--tar/test/test_extract_tar_lzma.c2
3 files changed, 6 insertions, 6 deletions
diff --git a/tar/test/test_extract_tar_lzma.c b/tar/test/test_extract_tar_lzma.c
index 977f6d69..2fa2af04 100644
--- a/tar/test/test_extract_tar_lzma.c
+++ b/tar/test/test_extract_tar_lzma.c
@@ -32,7 +32,7 @@ DEFINE_TEST(test_extract_tar_lzma)
extract_reference_file(reffile);
f = systemf("%s -tf %s >test.out 2>test.err", testprog, reffile);
- if (f == 0 || canUnlzma()) {
+ if (f == 0 || canLzma()) {
assertEqualInt(0, systemf("%s -xf %s >test.out 2>test.err",
testprog, reffile));
diff --git a/tar/test/main.c b/tar/test/main.c
index e0b15dc7..7ac57764 100644
--- a/tar/test/main.c
+++ b/tar/test/main.c
@@ -1918,15 +1918,15 @@ canLzip(void)
}
/*
* Can this platform run the unlzma program?
*/
int
-canUnlzma(void)
+canLzma(void)
{
static int tested = 0, value = 0;
if (!tested) {
tested = 1;
- if (systemf("unlzma -V %s", redirectArgs) == 0)
+ if (systemf("lzma -V %s", redirectArgs) == 0)
value = 1;
}
return (value);
@@ -1918,15 +1918,15 @@ canLzip(void)
}
/*
- * Can this platform run the unlzma program?
+ * Can this platform run the lzma program?
*/
int
diff --git a/tar/test/test.h b/tar/test/test.h
index d5a55cfb..1d910c6f 100644
--- a/tar/test/test.h
+++ b/tar/test/test.h
@@ -283,8 +283,8 @@ int canLrzip(void);
/* Return true if this platform can run the "lzip" program. */
int canLzip(void);
-/* Return true if this platform can run the "unlzma" program. */
-int canUnlzma(void);
+/* Return true if this platform can run the "lzma" program. */
+int canLzma(void);
/* Return true if this platform can run the "lzop" program. */
int canLzop(void);